Juan Lang : crypt32/tests: Fix another test failure on Win98.

Alexandre Julliard julliard at winehq.org
Wed Oct 6 14:04:21 CDT 2010


Module: wine
Branch: master
Commit: 251ccfc8486340dd30214f31bdfb46de56344a86
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=251ccfc8486340dd30214f31bdfb46de56344a86

Author: Juan Lang <juan.lang at gmail.com>
Date:   Wed Oct  6 10:28:12 2010 -0700

crypt32/tests: Fix another test failure on Win98.

---

 dlls/crypt32/tests/chain.c |    7 +++++--
 1 files changed, 5 insertions(+), 2 deletions(-)

diff --git a/dlls/crypt32/tests/chain.c b/dlls/crypt32/tests/chain.c
index 24831b5..2c62ec0 100644
--- a/dlls/crypt32/tests/chain.c
+++ b/dlls/crypt32/tests/chain.c
@@ -3506,10 +3506,13 @@ static ChainCheck chainCheck[] = {
    { { CERT_TRUST_IS_UNTRUSTED_ROOT, CERT_TRUST_HAS_PREFERRED_ISSUER },
      { 0, 0 },
        1, iTunesSimpleStatus }, 0 },
  /* The google chain may or may not have its root trusted, so ignore the error
   */
  { { sizeof(googleChain) / sizeof(googleChain[0]), googleChain },
-   { { CERT_TRUST_IS_UNTRUSTED_ROOT, CERT_TRUST_HAS_PREFERRED_ISSUER },
+   { { CERT_TRUST_IS_UNTRUSTED_ROOT | CERT_TRUST_IS_NOT_TIME_NESTED,
+       CERT_TRUST_HAS_PREFERRED_ISSUER },
      { CERT_TRUST_IS_NOT_TIME_VALID, 0 },
        1, googleSimpleStatus }, 0 },
  /* The openssl chain may or may not have its root trusted, so ignore the error
@@ -3506,10 +3506,13 @@ static ChainCheck chainCheck[] = {
      { 0, 0 },
        1, iTunesSimpleStatus }, 0 },
- /* The google chain may or may not have its root trusted, so ignore the error
+ /* The google chain may or may not have its root trusted, so ignore the error.
+  * The chain is also considered not time nested on Win98, so ignore that
+  * error too.
   */
  { { sizeof(googleChain) / sizeof(googleChain[0]), googleChain },




More information about the wine-cvs mailing list